principaltoken

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the principaltoken type in the database.
	Label = "principal_token"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldPrincipalID holds the string denoting the principal_id field in the database.
	FieldPrincipalID = "principal_id"
	// FieldPrincipalType holds the string denoting the principal_type field in the database.
	FieldPrincipalType = "principal_type"
	// FieldIssuedByAppID holds the string denoting the issued_by_app_id field in the database.
	FieldIssuedByAppID = "issued_by_app_id"
	// FieldAccessTokenSignature holds the string denoting the access_token_signature field in the database.
	FieldAccessTokenSignature = "access_token_signature"
	// FieldRefreshTokenSignature holds the string denoting the refresh_token_signature field in the database.
	FieldRefreshTokenSignature = "refresh_token_signature"
	// FieldFamilyID holds the string denoting the family_id field in the database.
	FieldFamilyID = "family_id"
	// FieldParentTokenID holds the string denoting the parent_token_id field in the database.
	FieldParentTokenID = "parent_token_id"
	// FieldScopes holds the string denoting the scopes field in the database.
	FieldScopes = "scopes"
	// FieldAudience holds the string denoting the audience field in the database.
	FieldAudience = "audience"
	// FieldCapabilities holds the string denoting the capabilities field in the database.
	FieldCapabilities = "capabilities"
	// FieldDelegationChain holds the string denoting the delegation_chain field in the database.
	FieldDelegationChain = "delegation_chain"
	// FieldDpopJkt holds the string denoting the dpop_jkt field in the database.
	FieldDpopJkt = "dpop_jkt"
	// FieldSessionID holds the string denoting the session_id field in the database.
	FieldSessionID = "session_id"
	// FieldRequestData holds the string denoting the request_data field in the database.
	FieldRequestData = "request_data"
	// FieldAccessExpiresAt holds the string denoting the access_expires_at field in the database.
	FieldAccessExpiresAt = "access_expires_at"
	// FieldRefreshExpiresAt holds the string denoting the refresh_expires_at field in the database.
	FieldRefreshExpiresAt = "refresh_expires_at"
	// FieldRevoked holds the string denoting the revoked field in the database.
	FieldRevoked = "revoked"
	// FieldRevokedAt holds the string denoting the revoked_at field in the database.
	FieldRevokedAt = "revoked_at"
	// FieldRevokedReason holds the string denoting the revoked_reason field in the database.
	FieldRevokedReason = "revoked_reason"
	// FieldClientIP holds the string denoting the client_ip field in the database.
	FieldClientIP = "client_ip"
	// FieldUserAgent holds the string denoting the user_agent field in the database.
	FieldUserAgent = "user_agent"
	// FieldLastUsedAt holds the string denoting the last_used_at field in the database.
	FieldLastUsedAt = "last_used_at"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgePrincipal holds the string denoting the principal edge name in mutations.
	EdgePrincipal = "principal"
	// EdgeIssuedByApp holds the string denoting the issued_by_app edge name in mutations.
	EdgeIssuedByApp = "issued_by_app"
	// EdgeParentToken holds the string denoting the parent_token edge name in mutations.
	EdgeParentToken = "parent_token"
	// EdgeChildTokens holds the string denoting the child_tokens edge name in mutations.
	EdgeChildTokens = "child_tokens"
	// Table holds the table name of the principaltoken in the database.
	Table = "cf_principal_tokens"
	// PrincipalTable is the table that holds the principal relation/edge.
	PrincipalTable = "cf_principal_tokens"
	// PrincipalInverseTable is the table name for the Principal entity.
	// It exists in this package in order to avoid circular dependency with the "principal" package.
	PrincipalInverseTable = "cf_principals"
	// PrincipalColumn is the table column denoting the principal relation/edge.
	PrincipalColumn = "principal_id"
	// IssuedByAppTable is the table that holds the issued_by_app relation/edge.
	IssuedByAppTable = "cf_principal_tokens"
	// IssuedByAppInverseTable is the table name for the Application entity.
	// It exists in this package in order to avoid circular dependency with the "application" package.
	IssuedByAppInverseTable = "cf_applications"
	// IssuedByAppColumn is the table column denoting the issued_by_app relation/edge.
	IssuedByAppColumn = "issued_by_app_id"
	// ParentTokenTable is the table that holds the parent_token relation/edge.
	ParentTokenTable = "cf_principal_tokens"
	// ParentTokenColumn is the table column denoting the parent_token relation/edge.
	ParentTokenColumn = "parent_token_id"
	// ChildTokensTable is the table that holds the child_tokens relation/edge.
	ChildTokensTable = "cf_principal_tokens"
	// ChildTokensColumn is the table column denoting the child_tokens relation/edge.
	ChildTokensColumn = "parent_token_id"
)

Variables

var (
	// DefaultFamilyID holds the default value on creation for the "family_id" field.
	DefaultFamilyID func() uuid.UUID
	// DefaultScopes holds the default value on creation for the "scopes" field.
	DefaultScopes []string
	// DefaultAudience holds the default value on creation for the "audience" field.
	DefaultAudience []string
	// DefaultCapabilities holds the default value on creation for the "capabilities" field.
	DefaultCapabilities map[string]bool
	// DefaultDelegationChain holds the default value on creation for the "delegation_chain" field.
	DefaultDelegationChain []string
	// DefaultRevoked holds the default value on creation for the "revoked" field.
	DefaultRevoked bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for principaltoken fields.

Functions

func AccessExpiresAt

func AccessExpiresAt(v time.Time) predicate.PrincipalToken

AccessExpiresAt applies equality check predicate on the "access_expires_at" field. It's identical to AccessExpiresAtEQ.

func AccessExpiresAtEQ

func AccessExpiresAtEQ(v time.Time) predicate.PrincipalToken

AccessExpiresAtEQ applies the EQ predicate on the "access_expires_at" field.

func AccessExpiresAtGT

func AccessExpiresAtGT(v time.Time) predicate.PrincipalToken

AccessExpiresAtGT applies the GT predicate on the "access_expires_at" field.

func AccessExpiresAtGTE

func AccessExpiresAtGTE(v time.Time) predicate.PrincipalToken

AccessExpiresAtGTE applies the GTE predicate on the "access_expires_at" field.

func AccessExpiresAtIn

func AccessExpiresAtIn(vs ...time.Time) predicate.PrincipalToken

AccessExpiresAtIn applies the In predicate on the "access_expires_at" field.

func AccessExpiresAtLT

func AccessExpiresAtLT(v time.Time) predicate.PrincipalToken

AccessExpiresAtLT applies the LT predicate on the "access_expires_at" field.

func AccessExpiresAtLTE

func AccessExpiresAtLTE(v time.Time) predicate.PrincipalToken

AccessExpiresAtLTE applies the LTE predicate on the "access_expires_at" field.

func AccessExpiresAtNEQ

func AccessExpiresAtNEQ(v time.Time) predicate.PrincipalToken

AccessExpiresAtNEQ applies the NEQ predicate on the "access_expires_at" field.

func AccessExpiresAtNotIn

func AccessExpiresAtNotIn(vs ...time.Time) predicate.PrincipalToken

AccessExpiresAtNotIn applies the NotIn predicate on the "access_expires_at" field.

func AccessTokenSignature

func AccessTokenSignature(v string) predicate.PrincipalToken

AccessTokenSignature applies equality check predicate on the "access_token_signature" field. It's identical to AccessTokenSignatureEQ.

func AccessTokenSignatureContains

func AccessTokenSignatureContains(v string) predicate.PrincipalToken

AccessTokenSignatureContains applies the Contains predicate on the "access_token_signature" field.

func AccessTokenSignatureContainsFold

func AccessTokenSignatureContainsFold(v string) predicate.PrincipalToken

AccessTokenSignatureContainsFold applies the ContainsFold predicate on the "access_token_signature" field.

func AccessTokenSignatureEQ

func AccessTokenSignatureEQ(v string) predicate.PrincipalToken

AccessTokenSignatureEQ applies the EQ predicate on the "access_token_signature" field.

func AccessTokenSignatureEqualFold

func AccessTokenSignatureEqualFold(v string) predicate.PrincipalToken

AccessTokenSignatureEqualFold applies the EqualFold predicate on the "access_token_signature" field.

func AccessTokenSignatureGT

func AccessTokenSignatureGT(v string) predicate.PrincipalToken

AccessTokenSignatureGT applies the GT predicate on the "access_token_signature" field.

func AccessTokenSignatureGTE

func AccessTokenSignatureGTE(v string) predicate.PrincipalToken

AccessTokenSignatureGTE applies the GTE predicate on the "access_token_signature" field.

func AccessTokenSignatureHasPrefix

func AccessTokenSignatureHasPrefix(v string) predicate.PrincipalToken

AccessTokenSignatureHasPrefix applies the HasPrefix predicate on the "access_token_signature" field.

func AccessTokenSignatureHasSuffix

func AccessTokenSignatureHasSuffix(v string) predicate.PrincipalToken

AccessTokenSignatureHasSuffix applies the HasSuffix predicate on the "access_token_signature" field.

func AccessTokenSignatureIn

func AccessTokenSignatureIn(vs ...string) predicate.PrincipalToken

AccessTokenSignatureIn applies the In predicate on the "access_token_signature" field.

func AccessTokenSignatureLT

func AccessTokenSignatureLT(v string) predicate.PrincipalToken

AccessTokenSignatureLT applies the LT predicate on the "access_token_signature" field.

func AccessTokenSignatureLTE

func AccessTokenSignatureLTE(v string) predicate.PrincipalToken

AccessTokenSignatureLTE applies the LTE predicate on the "access_token_signature" field.

func AccessTokenSignatureNEQ

func AccessTokenSignatureNEQ(v string) predicate.PrincipalToken

AccessTokenSignatureNEQ applies the NEQ predicate on the "access_token_signature" field.

func AccessTokenSignatureNotIn

func AccessTokenSignatureNotIn(vs ...string) predicate.PrincipalToken

AccessTokenSignatureNotIn applies the NotIn predicate on the "access_token_signature" field.

func And

And groups predicates with the AND operator between them.

func ClientIP

func ClientIP(v string) predicate.PrincipalToken

ClientIP applies equality check predicate on the "client_ip" field. It's identical to ClientIPEQ.

func ClientIPContains

func ClientIPContains(v string) predicate.PrincipalToken

ClientIPContains applies the Contains predicate on the "client_ip" field.

func ClientIPContainsFold

func ClientIPContainsFold(v string) predicate.PrincipalToken

ClientIPContainsFold applies the ContainsFold predicate on the "client_ip" field.

func ClientIPEQ

func ClientIPEQ(v string) predicate.PrincipalToken

ClientIPEQ applies the EQ predicate on the "client_ip" field.

func ClientIPEqualFold

func ClientIPEqualFold(v string) predicate.PrincipalToken

ClientIPEqualFold applies the EqualFold predicate on the "client_ip" field.

func ClientIPGT

func ClientIPGT(v string) predicate.PrincipalToken

ClientIPGT applies the GT predicate on the "client_ip" field.

func ClientIPGTE

func ClientIPGTE(v string) predicate.PrincipalToken

ClientIPGTE applies the GTE predicate on the "client_ip" field.

func ClientIPHasPrefix

func ClientIPHasPrefix(v string) predicate.PrincipalToken

ClientIPHasPrefix applies the HasPrefix predicate on the "client_ip" field.

func ClientIPHasSuffix

func ClientIPHasSuffix(v string) predicate.PrincipalToken

ClientIPHasSuffix applies the HasSuffix predicate on the "client_ip" field.

func ClientIPIn

func ClientIPIn(vs ...string) predicate.PrincipalToken

ClientIPIn applies the In predicate on the "client_ip" field.

func ClientIPIsNil

func ClientIPIsNil() predicate.PrincipalToken

ClientIPIsNil applies the IsNil predicate on the "client_ip" field.

func ClientIPLT

func ClientIPLT(v string) predicate.PrincipalToken

ClientIPLT applies the LT predicate on the "client_ip" field.

func ClientIPLTE

func ClientIPLTE(v string) predicate.PrincipalToken

ClientIPLTE applies the LTE predicate on the "client_ip" field.

func ClientIPNEQ

func ClientIPNEQ(v string) predicate.PrincipalToken

ClientIPNEQ applies the NEQ predicate on the "client_ip" field.

func ClientIPNotIn

func ClientIPNotIn(vs ...string) predicate.PrincipalToken

ClientIPNotIn applies the NotIn predicate on the "client_ip" field.

func ClientIPNotNil

func ClientIPNotNil() predicate.PrincipalToken

ClientIPNotNil applies the NotNil predicate on the "client_ip" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.PrincipalToken

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.PrincipalToken

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.PrincipalToken

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.PrincipalToken

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.PrincipalToken

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.PrincipalToken

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.PrincipalToken

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.PrincipalToken

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.PrincipalToken

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DpopJkt

func DpopJkt(v string) predicate.PrincipalToken

DpopJkt applies equality check predicate on the "dpop_jkt" field. It's identical to DpopJktEQ.

func DpopJktContains

func DpopJktContains(v string) predicate.PrincipalToken

DpopJktContains applies the Contains predicate on the "dpop_jkt" field.

func DpopJktContainsFold

func DpopJktContainsFold(v string) predicate.PrincipalToken

DpopJktContainsFold applies the ContainsFold predicate on the "dpop_jkt" field.

func DpopJktEQ

func DpopJktEQ(v string) predicate.PrincipalToken

DpopJktEQ applies the EQ predicate on the "dpop_jkt" field.

func DpopJktEqualFold

func DpopJktEqualFold(v string) predicate.PrincipalToken

DpopJktEqualFold applies the EqualFold predicate on the "dpop_jkt" field.

func DpopJktGT

func DpopJktGT(v string) predicate.PrincipalToken

DpopJktGT applies the GT predicate on the "dpop_jkt" field.

func DpopJktGTE

func DpopJktGTE(v string) predicate.PrincipalToken

DpopJktGTE applies the GTE predicate on the "dpop_jkt" field.

func DpopJktHasPrefix

func DpopJktHasPrefix(v string) predicate.PrincipalToken

DpopJktHasPrefix applies the HasPrefix predicate on the "dpop_jkt" field.

func DpopJktHasSuffix

func DpopJktHasSuffix(v string) predicate.PrincipalToken

DpopJktHasSuffix applies the HasSuffix predicate on the "dpop_jkt" field.

func DpopJktIn

func DpopJktIn(vs ...string) predicate.PrincipalToken

DpopJktIn applies the In predicate on the "dpop_jkt" field.

func DpopJktIsNil

func DpopJktIsNil() predicate.PrincipalToken

DpopJktIsNil applies the IsNil predicate on the "dpop_jkt" field.

func DpopJktLT

func DpopJktLT(v string) predicate.PrincipalToken

DpopJktLT applies the LT predicate on the "dpop_jkt" field.

func DpopJktLTE

func DpopJktLTE(v string) predicate.PrincipalToken

DpopJktLTE applies the LTE predicate on the "dpop_jkt" field.

func DpopJktNEQ

func DpopJktNEQ(v string) predicate.PrincipalToken

DpopJktNEQ applies the NEQ predicate on the "dpop_jkt" field.

func DpopJktNotIn

func DpopJktNotIn(vs ...string) predicate.PrincipalToken

DpopJktNotIn applies the NotIn predicate on the "dpop_jkt" field.

func DpopJktNotNil

func DpopJktNotNil() predicate.PrincipalToken

DpopJktNotNil applies the NotNil predicate on the "dpop_jkt" field.

func FamilyID

func FamilyID(v uuid.UUID) predicate.PrincipalToken

FamilyID applies equality check predicate on the "family_id" field. It's identical to FamilyIDEQ.

func FamilyIDEQ

func FamilyIDEQ(v uuid.UUID) predicate.PrincipalToken

FamilyIDEQ applies the EQ predicate on the "family_id" field.

func FamilyIDGT

func FamilyIDGT(v uuid.UUID) predicate.PrincipalToken

FamilyIDGT applies the GT predicate on the "family_id" field.

func FamilyIDGTE

func FamilyIDGTE(v uuid.UUID) predicate.PrincipalToken

FamilyIDGTE applies the GTE predicate on the "family_id" field.

func FamilyIDIn

func FamilyIDIn(vs ...uuid.UUID) predicate.PrincipalToken

FamilyIDIn applies the In predicate on the "family_id" field.

func FamilyIDLT

func FamilyIDLT(v uuid.UUID) predicate.PrincipalToken

FamilyIDLT applies the LT predicate on the "family_id" field.

func FamilyIDLTE

func FamilyIDLTE(v uuid.UUID) predicate.PrincipalToken

FamilyIDLTE applies the LTE predicate on the "family_id" field.

func FamilyIDNEQ

func FamilyIDNEQ(v uuid.UUID) predicate.PrincipalToken

FamilyIDNEQ applies the NEQ predicate on the "family_id" field.

func FamilyIDNotIn

func FamilyIDNotIn(vs ...uuid.UUID) predicate.PrincipalToken

FamilyIDNotIn applies the NotIn predicate on the "family_id" field.

func HasChildTokens

func HasChildTokens() predicate.PrincipalToken

HasChildTokens applies the HasEdge predicate on the "child_tokens" edge.

func HasChildTokensWith

func HasChildTokensWith(preds ...predicate.PrincipalToken) predicate.PrincipalToken

HasChildTokensWith applies the HasEdge predicate on the "child_tokens" edge with a given conditions (other predicates).

func HasIssuedByApp

func HasIssuedByApp() predicate.PrincipalToken

HasIssuedByApp applies the HasEdge predicate on the "issued_by_app" edge.

func HasIssuedByAppWith

func HasIssuedByAppWith(preds ...predicate.Application) predicate.PrincipalToken

HasIssuedByAppWith applies the HasEdge predicate on the "issued_by_app" edge with a given conditions (other predicates).

func HasParentToken

func HasParentToken() predicate.PrincipalToken

HasParentToken applies the HasEdge predicate on the "parent_token" edge.

func HasParentTokenWith

func HasParentTokenWith(preds ...predicate.PrincipalToken) predicate.PrincipalToken

HasParentTokenWith applies the HasEdge predicate on the "parent_token" edge with a given conditions (other predicates).

func HasPrincipal

func HasPrincipal() predicate.PrincipalToken

HasPrincipal applies the HasEdge predicate on the "principal" edge.

func HasPrincipalWith

func HasPrincipalWith(preds ...predicate.Principal) predicate.PrincipalToken

HasPrincipalWith applies the HasEdge predicate on the "principal" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.PrincipalToken

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.PrincipalToken

IDNotIn applies the NotIn predicate on the ID field.

func IssuedByAppID

func IssuedByAppID(v uuid.UUID) predicate.PrincipalToken

IssuedByAppID applies equality check predicate on the "issued_by_app_id" field. It's identical to IssuedByAppIDEQ.

func IssuedByAppIDEQ

func IssuedByAppIDEQ(v uuid.UUID) predicate.PrincipalToken

IssuedByAppIDEQ applies the EQ predicate on the "issued_by_app_id" field.

func IssuedByAppIDIn

func IssuedByAppIDIn(vs ...uuid.UUID) predicate.PrincipalToken

IssuedByAppIDIn applies the In predicate on the "issued_by_app_id" field.

func IssuedByAppIDIsNil

func IssuedByAppIDIsNil() predicate.PrincipalToken

IssuedByAppIDIsNil applies the IsNil predicate on the "issued_by_app_id" field.

func IssuedByAppIDNEQ

func IssuedByAppIDNEQ(v uuid.UUID) predicate.PrincipalToken

IssuedByAppIDNEQ applies the NEQ predicate on the "issued_by_app_id" field.

func IssuedByAppIDNotIn

func IssuedByAppIDNotIn(vs ...uuid.UUID) predicate.PrincipalToken

IssuedByAppIDNotIn applies the NotIn predicate on the "issued_by_app_id" field.

func IssuedByAppIDNotNil

func IssuedByAppIDNotNil() predicate.PrincipalToken

IssuedByAppIDNotNil applies the NotNil predicate on the "issued_by_app_id" field.

func LastUsedAt

func LastUsedAt(v time.Time) predicate.PrincipalToken

LastUsedAt applies equality check predicate on the "last_used_at" field. It's identical to LastUsedAtEQ.

func LastUsedAtEQ

func LastUsedAtEQ(v time.Time) predicate.PrincipalToken

LastUsedAtEQ applies the EQ predicate on the "last_used_at" field.

func LastUsedAtGT

func LastUsedAtGT(v time.Time) predicate.PrincipalToken

LastUsedAtGT applies the GT predicate on the "last_used_at" field.

func LastUsedAtGTE

func LastUsedAtGTE(v time.Time) predicate.PrincipalToken

LastUsedAtGTE applies the GTE predicate on the "last_used_at" field.

func LastUsedAtIn

func LastUsedAtIn(vs ...time.Time) predicate.PrincipalToken

LastUsedAtIn applies the In predicate on the "last_used_at" field.

func LastUsedAtIsNil

func LastUsedAtIsNil() predicate.PrincipalToken

LastUsedAtIsNil applies the IsNil predicate on the "last_used_at" field.

func LastUsedAtLT

func LastUsedAtLT(v time.Time) predicate.PrincipalToken

LastUsedAtLT applies the LT predicate on the "last_used_at" field.

func LastUsedAtLTE

func LastUsedAtLTE(v time.Time) predicate.PrincipalToken

LastUsedAtLTE applies the LTE predicate on the "last_used_at" field.

func LastUsedAtNEQ

func LastUsedAtNEQ(v time.Time) predicate.PrincipalToken

LastUsedAtNEQ applies the NEQ predicate on the "last_used_at" field.

func LastUsedAtNotIn

func LastUsedAtNotIn(vs ...time.Time) predicate.PrincipalToken

LastUsedAtNotIn applies the NotIn predicate on the "last_used_at" field.

func LastUsedAtNotNil

func LastUsedAtNotNil() predicate.PrincipalToken

LastUsedAtNotNil applies the NotNil predicate on the "last_used_at" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func ParentTokenID

func ParentTokenID(v uuid.UUID) predicate.PrincipalToken

ParentTokenID applies equality check predicate on the "parent_token_id" field. It's identical to ParentTokenIDEQ.

func ParentTokenIDEQ

func ParentTokenIDEQ(v uuid.UUID) predicate.PrincipalToken

ParentTokenIDEQ applies the EQ predicate on the "parent_token_id" field.

func ParentTokenIDIn

func ParentTokenIDIn(vs ...uuid.UUID) predicate.PrincipalToken

ParentTokenIDIn applies the In predicate on the "parent_token_id" field.

func ParentTokenIDIsNil

func ParentTokenIDIsNil() predicate.PrincipalToken

ParentTokenIDIsNil applies the IsNil predicate on the "parent_token_id" field.

func ParentTokenIDNEQ

func ParentTokenIDNEQ(v uuid.UUID) predicate.PrincipalToken

ParentTokenIDNEQ applies the NEQ predicate on the "parent_token_id" field.

func ParentTokenIDNotIn

func ParentTokenIDNotIn(vs ...uuid.UUID) predicate.PrincipalToken

ParentTokenIDNotIn applies the NotIn predicate on the "parent_token_id" field.

func ParentTokenIDNotNil

func ParentTokenIDNotNil() predicate.PrincipalToken

ParentTokenIDNotNil applies the NotNil predicate on the "parent_token_id" field.

func PrincipalID

func PrincipalID(v uuid.UUID) predicate.PrincipalToken

PrincipalID applies equality check predicate on the "principal_id" field. It's identical to PrincipalIDEQ.

func PrincipalIDEQ

func PrincipalIDEQ(v uuid.UUID) predicate.PrincipalToken

PrincipalIDEQ applies the EQ predicate on the "principal_id" field.

func PrincipalIDIn

func PrincipalIDIn(vs ...uuid.UUID) predicate.PrincipalToken

PrincipalIDIn applies the In predicate on the "principal_id" field.

func PrincipalIDNEQ

func PrincipalIDNEQ(v uuid.UUID) predicate.PrincipalToken

PrincipalIDNEQ applies the NEQ predicate on the "principal_id" field.

func PrincipalIDNotIn

func PrincipalIDNotIn(vs ...uuid.UUID) predicate.PrincipalToken

PrincipalIDNotIn applies the NotIn predicate on the "principal_id" field.

func PrincipalTypeEQ

func PrincipalTypeEQ(v PrincipalType) predicate.PrincipalToken

PrincipalTypeEQ applies the EQ predicate on the "principal_type" field.

func PrincipalTypeIn

func PrincipalTypeIn(vs ...PrincipalType) predicate.PrincipalToken

PrincipalTypeIn applies the In predicate on the "principal_type" field.

func PrincipalTypeNEQ

func PrincipalTypeNEQ(v PrincipalType) predicate.PrincipalToken

PrincipalTypeNEQ applies the NEQ predicate on the "principal_type" field.

func PrincipalTypeNotIn

func PrincipalTypeNotIn(vs ...PrincipalType) predicate.PrincipalToken

PrincipalTypeNotIn applies the NotIn predicate on the "principal_type" field.

func PrincipalTypeValidator

func PrincipalTypeValidator(pt PrincipalType) error

PrincipalTypeValidator is a validator for the "principal_type" field enum values. It is called by the builders before save.

func RefreshExpiresAt

func RefreshExpiresAt(v time.Time) predicate.PrincipalToken

RefreshExpiresAt applies equality check predicate on the "refresh_expires_at" field. It's identical to RefreshExpiresAtEQ.

func RefreshExpiresAtEQ

func RefreshExpiresAtEQ(v time.Time) predicate.PrincipalToken

RefreshExpiresAtEQ applies the EQ predicate on the "refresh_expires_at" field.

func RefreshExpiresAtGT

func RefreshExpiresAtGT(v time.Time) predicate.PrincipalToken

RefreshExpiresAtGT applies the GT predicate on the "refresh_expires_at" field.

func RefreshExpiresAtGTE

func RefreshExpiresAtGTE(v time.Time) predicate.PrincipalToken

RefreshExpiresAtGTE applies the GTE predicate on the "refresh_expires_at" field.

func RefreshExpiresAtIn

func RefreshExpiresAtIn(vs ...time.Time) predicate.PrincipalToken

RefreshExpiresAtIn applies the In predicate on the "refresh_expires_at" field.

func RefreshExpiresAtIsNil

func RefreshExpiresAtIsNil() predicate.PrincipalToken

RefreshExpiresAtIsNil applies the IsNil predicate on the "refresh_expires_at" field.

func RefreshExpiresAtLT

func RefreshExpiresAtLT(v time.Time) predicate.PrincipalToken

RefreshExpiresAtLT applies the LT predicate on the "refresh_expires_at" field.

func RefreshExpiresAtLTE

func RefreshExpiresAtLTE(v time.Time) predicate.PrincipalToken

RefreshExpiresAtLTE applies the LTE predicate on the "refresh_expires_at" field.

func RefreshExpiresAtNEQ

func RefreshExpiresAtNEQ(v time.Time) predicate.PrincipalToken

RefreshExpiresAtNEQ applies the NEQ predicate on the "refresh_expires_at" field.

func RefreshExpiresAtNotIn

func RefreshExpiresAtNotIn(vs ...time.Time) predicate.PrincipalToken

RefreshExpiresAtNotIn applies the NotIn predicate on the "refresh_expires_at" field.

func RefreshExpiresAtNotNil

func RefreshExpiresAtNotNil() predicate.PrincipalToken

RefreshExpiresAtNotNil applies the NotNil predicate on the "refresh_expires_at" field.

func RefreshTokenSignature

func RefreshTokenSignature(v string) predicate.PrincipalToken

RefreshTokenSignature applies equality check predicate on the "refresh_token_signature" field. It's identical to RefreshTokenSignatureEQ.

func RefreshTokenSignatureContains

func RefreshTokenSignatureContains(v string) predicate.PrincipalToken

RefreshTokenSignatureContains applies the Contains predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureContainsFold

func RefreshTokenSignatureContainsFold(v string) predicate.PrincipalToken

RefreshTokenSignatureContainsFold applies the ContainsFold predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureEQ

func RefreshTokenSignatureEQ(v string) predicate.PrincipalToken

RefreshTokenSignatureEQ applies the EQ predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureEqualFold

func RefreshTokenSignatureEqualFold(v string) predicate.PrincipalToken

RefreshTokenSignatureEqualFold applies the EqualFold predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureGT

func RefreshTokenSignatureGT(v string) predicate.PrincipalToken

RefreshTokenSignatureGT applies the GT predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureGTE

func RefreshTokenSignatureGTE(v string) predicate.PrincipalToken

RefreshTokenSignatureGTE applies the GTE predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureHasPrefix

func RefreshTokenSignatureHasPrefix(v string) predicate.PrincipalToken

RefreshTokenSignatureHasPrefix applies the HasPrefix predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureHasSuffix

func RefreshTokenSignatureHasSuffix(v string) predicate.PrincipalToken

RefreshTokenSignatureHasSuffix applies the HasSuffix predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureIn

func RefreshTokenSignatureIn(vs ...string) predicate.PrincipalToken

RefreshTokenSignatureIn applies the In predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureIsNil

func RefreshTokenSignatureIsNil() predicate.PrincipalToken

RefreshTokenSignatureIsNil applies the IsNil predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureLT

func RefreshTokenSignatureLT(v string) predicate.PrincipalToken

RefreshTokenSignatureLT applies the LT predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureLTE

func RefreshTokenSignatureLTE(v string) predicate.PrincipalToken

RefreshTokenSignatureLTE applies the LTE predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureNEQ

func RefreshTokenSignatureNEQ(v string) predicate.PrincipalToken

RefreshTokenSignatureNEQ applies the NEQ predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureNotIn

func RefreshTokenSignatureNotIn(vs ...string) predicate.PrincipalToken

RefreshTokenSignatureNotIn applies the NotIn predicate on the "refresh_token_signature" field.

func RefreshTokenSignatureNotNil

func RefreshTokenSignatureNotNil() predicate.PrincipalToken

RefreshTokenSignatureNotNil applies the NotNil predicate on the "refresh_token_signature" field.

func RequestData

func RequestData(v string) predicate.PrincipalToken

RequestData applies equality check predicate on the "request_data" field. It's identical to RequestDataEQ.

func RequestDataContains

func RequestDataContains(v string) predicate.PrincipalToken

RequestDataContains applies the Contains predicate on the "request_data" field.

func RequestDataContainsFold

func RequestDataContainsFold(v string) predicate.PrincipalToken

RequestDataContainsFold applies the ContainsFold predicate on the "request_data" field.

func RequestDataEQ

func RequestDataEQ(v string) predicate.PrincipalToken

RequestDataEQ applies the EQ predicate on the "request_data" field.

func RequestDataEqualFold

func RequestDataEqualFold(v string) predicate.PrincipalToken

RequestDataEqualFold applies the EqualFold predicate on the "request_data" field.

func RequestDataGT

func RequestDataGT(v string) predicate.PrincipalToken

RequestDataGT applies the GT predicate on the "request_data" field.

func RequestDataGTE

func RequestDataGTE(v string) predicate.PrincipalToken

RequestDataGTE applies the GTE predicate on the "request_data" field.

func RequestDataHasPrefix

func RequestDataHasPrefix(v string) predicate.PrincipalToken

RequestDataHasPrefix applies the HasPrefix predicate on the "request_data" field.

func RequestDataHasSuffix

func RequestDataHasSuffix(v string) predicate.PrincipalToken

RequestDataHasSuffix applies the HasSuffix predicate on the "request_data" field.

func RequestDataIn

func RequestDataIn(vs ...string) predicate.PrincipalToken

RequestDataIn applies the In predicate on the "request_data" field.

func RequestDataIsNil

func RequestDataIsNil() predicate.PrincipalToken

RequestDataIsNil applies the IsNil predicate on the "request_data" field.

func RequestDataLT

func RequestDataLT(v string) predicate.PrincipalToken

RequestDataLT applies the LT predicate on the "request_data" field.

func RequestDataLTE

func RequestDataLTE(v string) predicate.PrincipalToken

RequestDataLTE applies the LTE predicate on the "request_data" field.

func RequestDataNEQ

func RequestDataNEQ(v string) predicate.PrincipalToken

RequestDataNEQ applies the NEQ predicate on the "request_data" field.

func RequestDataNotIn

func RequestDataNotIn(vs ...string) predicate.PrincipalToken

RequestDataNotIn applies the NotIn predicate on the "request_data" field.

func RequestDataNotNil

func RequestDataNotNil() predicate.PrincipalToken

RequestDataNotNil applies the NotNil predicate on the "request_data" field.

func Revoked

func Revoked(v bool) predicate.PrincipalToken

Revoked applies equality check predicate on the "revoked" field. It's identical to RevokedEQ.

func RevokedAt

func RevokedAt(v time.Time) predicate.PrincipalToken

RevokedAt applies equality check predicate on the "revoked_at" field. It's identical to RevokedAtEQ.

func RevokedAtEQ

func RevokedAtEQ(v time.Time) predicate.PrincipalToken

RevokedAtEQ applies the EQ predicate on the "revoked_at" field.

func RevokedAtGT

func RevokedAtGT(v time.Time) predicate.PrincipalToken

RevokedAtGT applies the GT predicate on the "revoked_at" field.

func RevokedAtGTE

func RevokedAtGTE(v time.Time) predicate.PrincipalToken

RevokedAtGTE applies the GTE predicate on the "revoked_at" field.

func RevokedAtIn

func RevokedAtIn(vs ...time.Time) predicate.PrincipalToken

RevokedAtIn applies the In predicate on the "revoked_at" field.

func RevokedAtIsNil

func RevokedAtIsNil() predicate.PrincipalToken

RevokedAtIsNil applies the IsNil predicate on the "revoked_at" field.

func RevokedAtLT

func RevokedAtLT(v time.Time) predicate.PrincipalToken

RevokedAtLT applies the LT predicate on the "revoked_at" field.

func RevokedAtLTE

func RevokedAtLTE(v time.Time) predicate.PrincipalToken

RevokedAtLTE applies the LTE predicate on the "revoked_at" field.

func RevokedAtNEQ

func RevokedAtNEQ(v time.Time) predicate.PrincipalToken

RevokedAtNEQ applies the NEQ predicate on the "revoked_at" field.

func RevokedAtNotIn

func RevokedAtNotIn(vs ...time.Time) predicate.PrincipalToken

RevokedAtNotIn applies the NotIn predicate on the "revoked_at" field.

func RevokedAtNotNil

func RevokedAtNotNil() predicate.PrincipalToken

RevokedAtNotNil applies the NotNil predicate on the "revoked_at" field.

func RevokedEQ

func RevokedEQ(v bool) predicate.PrincipalToken

RevokedEQ applies the EQ predicate on the "revoked" field.

func RevokedNEQ

func RevokedNEQ(v bool) predicate.PrincipalToken

RevokedNEQ applies the NEQ predicate on the "revoked" field.

func RevokedReason

func RevokedReason(v string) predicate.PrincipalToken

RevokedReason applies equality check predicate on the "revoked_reason" field. It's identical to RevokedReasonEQ.

func RevokedReasonContains

func RevokedReasonContains(v string) predicate.PrincipalToken

RevokedReasonContains applies the Contains predicate on the "revoked_reason" field.

func RevokedReasonContainsFold

func RevokedReasonContainsFold(v string) predicate.PrincipalToken

RevokedReasonContainsFold applies the ContainsFold predicate on the "revoked_reason" field.

func RevokedReasonEQ

func RevokedReasonEQ(v string) predicate.PrincipalToken

RevokedReasonEQ applies the EQ predicate on the "revoked_reason" field.

func RevokedReasonEqualFold

func RevokedReasonEqualFold(v string) predicate.PrincipalToken

RevokedReasonEqualFold applies the EqualFold predicate on the "revoked_reason" field.

func RevokedReasonGT

func RevokedReasonGT(v string) predicate.PrincipalToken

RevokedReasonGT applies the GT predicate on the "revoked_reason" field.

func RevokedReasonGTE

func RevokedReasonGTE(v string) predicate.PrincipalToken

RevokedReasonGTE applies the GTE predicate on the "revoked_reason" field.

func RevokedReasonHasPrefix

func RevokedReasonHasPrefix(v string) predicate.PrincipalToken

RevokedReasonHasPrefix applies the HasPrefix predicate on the "revoked_reason" field.

func RevokedReasonHasSuffix

func RevokedReasonHasSuffix(v string) predicate.PrincipalToken

RevokedReasonHasSuffix applies the HasSuffix predicate on the "revoked_reason" field.

func RevokedReasonIn

func RevokedReasonIn(vs ...string) predicate.PrincipalToken

RevokedReasonIn applies the In predicate on the "revoked_reason" field.

func RevokedReasonIsNil

func RevokedReasonIsNil() predicate.PrincipalToken

RevokedReasonIsNil applies the IsNil predicate on the "revoked_reason" field.

func RevokedReasonLT

func RevokedReasonLT(v string) predicate.PrincipalToken

RevokedReasonLT applies the LT predicate on the "revoked_reason" field.

func RevokedReasonLTE

func RevokedReasonLTE(v string) predicate.PrincipalToken

RevokedReasonLTE applies the LTE predicate on the "revoked_reason" field.

func RevokedReasonNEQ

func RevokedReasonNEQ(v string) predicate.PrincipalToken

RevokedReasonNEQ applies the NEQ predicate on the "revoked_reason" field.

func RevokedReasonNotIn

func RevokedReasonNotIn(vs ...string) predicate.PrincipalToken

RevokedReasonNotIn applies the NotIn predicate on the "revoked_reason" field.

func RevokedReasonNotNil

func RevokedReasonNotNil() predicate.PrincipalToken

RevokedReasonNotNil applies the NotNil predicate on the "revoked_reason" field.

func SessionID

func SessionID(v string) predicate.PrincipalToken

SessionID applies equality check predicate on the "session_id" field. It's identical to SessionIDEQ.

func SessionIDContains

func SessionIDContains(v string) predicate.PrincipalToken

SessionIDContains applies the Contains predicate on the "session_id" field.

func SessionIDContainsFold

func SessionIDContainsFold(v string) predicate.PrincipalToken

SessionIDContainsFold applies the ContainsFold predicate on the "session_id" field.

func SessionIDEQ

func SessionIDEQ(v string) predicate.PrincipalToken

SessionIDEQ applies the EQ predicate on the "session_id" field.

func SessionIDEqualFold

func SessionIDEqualFold(v string) predicate.PrincipalToken

SessionIDEqualFold applies the EqualFold predicate on the "session_id" field.

func SessionIDGT

func SessionIDGT(v string) predicate.PrincipalToken

SessionIDGT applies the GT predicate on the "session_id" field.

func SessionIDGTE

func SessionIDGTE(v string) predicate.PrincipalToken

SessionIDGTE applies the GTE predicate on the "session_id" field.

func SessionIDHasPrefix

func SessionIDHasPrefix(v string) predicate.PrincipalToken

SessionIDHasPrefix applies the HasPrefix predicate on the "session_id" field.

func SessionIDHasSuffix

func SessionIDHasSuffix(v string) predicate.PrincipalToken

SessionIDHasSuffix applies the HasSuffix predicate on the "session_id" field.

func SessionIDIn

func SessionIDIn(vs ...string) predicate.PrincipalToken

SessionIDIn applies the In predicate on the "session_id" field.

func SessionIDIsNil

func SessionIDIsNil() predicate.PrincipalToken

SessionIDIsNil applies the IsNil predicate on the "session_id" field.

func SessionIDLT

func SessionIDLT(v string) predicate.PrincipalToken

SessionIDLT applies the LT predicate on the "session_id" field.

func SessionIDLTE

func SessionIDLTE(v string) predicate.PrincipalToken

SessionIDLTE applies the LTE predicate on the "session_id" field.

func SessionIDNEQ

func SessionIDNEQ(v string) predicate.PrincipalToken

SessionIDNEQ applies the NEQ predicate on the "session_id" field.

func SessionIDNotIn

func SessionIDNotIn(vs ...string) predicate.PrincipalToken

SessionIDNotIn applies the NotIn predicate on the "session_id" field.

func SessionIDNotNil

func SessionIDNotNil() predicate.PrincipalToken

SessionIDNotNil applies the NotNil predicate on the "session_id" field.

func UserAgent

func UserAgent(v string) predicate.PrincipalToken

UserAgent applies equality check predicate on the "user_agent" field. It's identical to UserAgentEQ.

func UserAgentContains

func UserAgentContains(v string) predicate.PrincipalToken

UserAgentContains applies the Contains predicate on the "user_agent" field.

func UserAgentContainsFold

func UserAgentContainsFold(v string) predicate.PrincipalToken

UserAgentContainsFold applies the ContainsFold predicate on the "user_agent" field.

func UserAgentEQ

func UserAgentEQ(v string) predicate.PrincipalToken

UserAgentEQ applies the EQ predicate on the "user_agent" field.

func UserAgentEqualFold

func UserAgentEqualFold(v string) predicate.PrincipalToken

UserAgentEqualFold applies the EqualFold predicate on the "user_agent" field.

func UserAgentGT

func UserAgentGT(v string) predicate.PrincipalToken

UserAgentGT applies the GT predicate on the "user_agent" field.

func UserAgentGTE

func UserAgentGTE(v string) predicate.PrincipalToken

UserAgentGTE applies the GTE predicate on the "user_agent" field.

func UserAgentHasPrefix

func UserAgentHasPrefix(v string) predicate.PrincipalToken

UserAgentHasPrefix applies the HasPrefix predicate on the "user_agent" field.

func UserAgentHasSuffix

func UserAgentHasSuffix(v string) predicate.PrincipalToken

UserAgentHasSuffix applies the HasSuffix predicate on the "user_agent" field.

func UserAgentIn

func UserAgentIn(vs ...string) predicate.PrincipalToken

UserAgentIn applies the In predicate on the "user_agent" field.

func UserAgentIsNil

func UserAgentIsNil() predicate.PrincipalToken

UserAgentIsNil applies the IsNil predicate on the "user_agent" field.

func UserAgentLT

func UserAgentLT(v string) predicate.PrincipalToken

UserAgentLT applies the LT predicate on the "user_agent" field.

func UserAgentLTE

func UserAgentLTE(v string) predicate.PrincipalToken

UserAgentLTE applies the LTE predicate on the "user_agent" field.

func UserAgentNEQ

func UserAgentNEQ(v string) predicate.PrincipalToken

UserAgentNEQ applies the NEQ predicate on the "user_agent" field.

func UserAgentNotIn

func UserAgentNotIn(vs ...string) predicate.PrincipalToken

UserAgentNotIn applies the NotIn predicate on the "user_agent" field.

func UserAgentNotNil

func UserAgentNotNil() predicate.PrincipalToken

UserAgentNotNil applies the NotNil predicate on the "user_agent" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the PrincipalToken queries.

func ByAccessExpiresAt

func ByAccessExpiresAt(opts ...sql.OrderTermOption) OrderOption

ByAccessExpiresAt orders the results by the access_expires_at field.

func ByAccessTokenSignature

func ByAccessTokenSignature(opts ...sql.OrderTermOption) OrderOption

ByAccessTokenSignature orders the results by the access_token_signature field.

func ByChildTokens

func ByChildTokens(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByChildTokens orders the results by child_tokens terms.

func ByChildTokensCount

func ByChildTokensCount(opts ...sql.OrderTermOption) OrderOption

ByChildTokensCount orders the results by child_tokens count.

func ByClientIP

func ByClientIP(opts ...sql.OrderTermOption) OrderOption

ByClientIP orders the results by the client_ip field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDpopJkt

func ByDpopJkt(opts ...sql.OrderTermOption) OrderOption

ByDpopJkt orders the results by the dpop_jkt field.

func ByFamilyID

func ByFamilyID(opts ...sql.OrderTermOption) OrderOption

ByFamilyID orders the results by the family_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIssuedByAppField

func ByIssuedByAppField(field string, opts ...sql.OrderTermOption) OrderOption

ByIssuedByAppField orders the results by issued_by_app field.

func ByIssuedByAppID

func ByIssuedByAppID(opts ...sql.OrderTermOption) OrderOption

ByIssuedByAppID orders the results by the issued_by_app_id field.

func ByLastUsedAt

func ByLastUsedAt(opts ...sql.OrderTermOption) OrderOption

ByLastUsedAt orders the results by the last_used_at field.

func ByParentTokenField

func ByParentTokenField(field string, opts ...sql.OrderTermOption) OrderOption

ByParentTokenField orders the results by parent_token field.

func ByParentTokenID

func ByParentTokenID(opts ...sql.OrderTermOption) OrderOption

ByParentTokenID orders the results by the parent_token_id field.

func ByPrincipalField

func ByPrincipalField(field string, opts ...sql.OrderTermOption) OrderOption

ByPrincipalField orders the results by principal field.

func ByPrincipalID

func ByPrincipalID(opts ...sql.OrderTermOption) OrderOption

ByPrincipalID orders the results by the principal_id field.

func ByPrincipalType

func ByPrincipalType(opts ...sql.OrderTermOption) OrderOption

ByPrincipalType orders the results by the principal_type field.

func ByRefreshExpiresAt

func ByRefreshExpiresAt(opts ...sql.OrderTermOption) OrderOption

ByRefreshExpiresAt orders the results by the refresh_expires_at field.

func ByRefreshTokenSignature

func ByRefreshTokenSignature(opts ...sql.OrderTermOption) OrderOption

ByRefreshTokenSignature orders the results by the refresh_token_signature field.

func ByRequestData

func ByRequestData(opts ...sql.OrderTermOption) OrderOption

ByRequestData orders the results by the request_data field.

func ByRevoked

func ByRevoked(opts ...sql.OrderTermOption) OrderOption

ByRevoked orders the results by the revoked field.

func ByRevokedAt

func ByRevokedAt(opts ...sql.OrderTermOption) OrderOption

ByRevokedAt orders the results by the revoked_at field.

func ByRevokedReason

func ByRevokedReason(opts ...sql.OrderTermOption) OrderOption

ByRevokedReason orders the results by the revoked_reason field.

func BySessionID

func BySessionID(opts ...sql.OrderTermOption) OrderOption

BySessionID orders the results by the session_id field.

func ByUserAgent

func ByUserAgent(opts ...sql.OrderTermOption) OrderOption

ByUserAgent orders the results by the user_agent field.

type PrincipalType

type PrincipalType string

PrincipalType defines the type for the "principal_type" enum field.

const (
	PrincipalTypeHuman       PrincipalType = "human"
	PrincipalTypeApplication PrincipalType = "application"
	PrincipalTypeAgent       PrincipalType = "agent"
	PrincipalTypeService     PrincipalType = "service"
)

PrincipalType values.

func (PrincipalType) String

func (pt PrincipalType) String() string

Jump to