serviceaccountkeypair

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the serviceaccountkeypair type in the database.
	Label = "service_account_key_pair"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldServiceAccountID holds the string denoting the service_account_id field in the database.
	FieldServiceAccountID = "service_account_id"
	// FieldKeyID holds the string denoting the key_id field in the database.
	FieldKeyID = "key_id"
	// FieldKeyType holds the string denoting the key_type field in the database.
	FieldKeyType = "key_type"
	// FieldAlgorithm holds the string denoting the algorithm field in the database.
	FieldAlgorithm = "algorithm"
	// FieldPublicKeyPem holds the string denoting the public_key_pem field in the database.
	FieldPublicKeyPem = "public_key_pem"
	// FieldExpiresAt holds the string denoting the expires_at field in the database.
	FieldExpiresAt = "expires_at"
	// FieldActive holds the string denoting the active field in the database.
	FieldActive = "active"
	// FieldLastUsedAt holds the string denoting the last_used_at field in the database.
	FieldLastUsedAt = "last_used_at"
	// FieldRevoked holds the string denoting the revoked field in the database.
	FieldRevoked = "revoked"
	// FieldRevokedAt holds the string denoting the revoked_at field in the database.
	FieldRevokedAt = "revoked_at"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgeServiceAccount holds the string denoting the service_account edge name in mutations.
	EdgeServiceAccount = "service_account"
	// Table holds the table name of the serviceaccountkeypair in the database.
	Table = "cf_service_account_key_pairs"
	// ServiceAccountTable is the table that holds the service_account relation/edge.
	ServiceAccountTable = "cf_service_account_key_pairs"
	// ServiceAccountInverseTable is the table name for the ServiceAccount entity.
	// It exists in this package in order to avoid circular dependency with the "serviceaccount" package.
	ServiceAccountInverseTable = "cf_service_accounts"
	// ServiceAccountColumn is the table column denoting the service_account relation/edge.
	ServiceAccountColumn = "service_account_id"
)
const DefaultAlgorithm = AlgorithmRS256

AlgorithmRS256 is the default value of the Algorithm enum.

const DefaultKeyType = KeyTypeRsa

KeyTypeRsa is the default value of the KeyType enum.

Variables

var (
	// KeyIDValidator is a validator for the "key_id" field. It is called by the builders before save.
	KeyIDValidator func(string) error
	// PublicKeyPemValidator is a validator for the "public_key_pem" field. It is called by the builders before save.
	PublicKeyPemValidator func(string) error
	// DefaultActive holds the default value on creation for the "active" field.
	DefaultActive bool
	// DefaultRevoked holds the default value on creation for the "revoked" field.
	DefaultRevoked bool
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for serviceaccountkeypair fields.

Functions

func Active

Active applies equality check predicate on the "active" field. It's identical to ActiveEQ.

func ActiveEQ

ActiveEQ applies the EQ predicate on the "active" field.

func ActiveNEQ

ActiveNEQ applies the NEQ predicate on the "active" field.

func AlgorithmEQ

AlgorithmEQ applies the EQ predicate on the "algorithm" field.

func AlgorithmIn

func AlgorithmIn(vs ...Algorithm) predicate.ServiceAccountKeyPair

AlgorithmIn applies the In predicate on the "algorithm" field.

func AlgorithmNEQ

AlgorithmNEQ applies the NEQ predicate on the "algorithm" field.

func AlgorithmNotIn

func AlgorithmNotIn(vs ...Algorithm) predicate.ServiceAccountKeyPair

AlgorithmNotIn applies the NotIn predicate on the "algorithm" field.

func AlgorithmValidator

func AlgorithmValidator(a Algorithm) error

AlgorithmValidator is a validator for the "algorithm" field enum values. It is called by the builders before save.

func And

And groups predicates with the AND operator between them.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.ServiceAccountKeyPair

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.ServiceAccountKeyPair

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.ServiceAccountKeyPair

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.ServiceAccountKeyPair

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.ServiceAccountKeyPair

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func ExpiresAt

ExpiresAt applies equality check predicate on the "expires_at" field. It's identical to ExpiresAtEQ.

func ExpiresAtEQ

ExpiresAtEQ applies the EQ predicate on the "expires_at" field.

func ExpiresAtGT

ExpiresAtGT applies the GT predicate on the "expires_at" field.

func ExpiresAtGTE

func ExpiresAtGTE(v time.Time) predicate.ServiceAccountKeyPair

ExpiresAtGTE applies the GTE predicate on the "expires_at" field.

func ExpiresAtIn

func ExpiresAtIn(vs ...time.Time) predicate.ServiceAccountKeyPair

ExpiresAtIn applies the In predicate on the "expires_at" field.

func ExpiresAtIsNil

func ExpiresAtIsNil() predicate.ServiceAccountKeyPair

ExpiresAtIsNil applies the IsNil predicate on the "expires_at" field.

func ExpiresAtLT

ExpiresAtLT applies the LT predicate on the "expires_at" field.

func ExpiresAtLTE

func ExpiresAtLTE(v time.Time) predicate.ServiceAccountKeyPair

ExpiresAtLTE applies the LTE predicate on the "expires_at" field.

func ExpiresAtNEQ

func ExpiresAtNEQ(v time.Time) predicate.ServiceAccountKeyPair

ExpiresAtNEQ applies the NEQ predicate on the "expires_at" field.

func ExpiresAtNotIn

func ExpiresAtNotIn(vs ...time.Time) predicate.ServiceAccountKeyPair

ExpiresAtNotIn applies the NotIn predicate on the "expires_at" field.

func ExpiresAtNotNil

func ExpiresAtNotNil() predicate.ServiceAccountKeyPair

ExpiresAtNotNil applies the NotNil predicate on the "expires_at" field.

func HasServiceAccount

func HasServiceAccount() predicate.ServiceAccountKeyPair

HasServiceAccount applies the HasEdge predicate on the "service_account" edge.

func HasServiceAccountWith

func HasServiceAccountWith(preds ...predicate.ServiceAccount) predicate.ServiceAccountKeyPair

HasServiceAccountWith applies the HasEdge predicate on the "service_account" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.ServiceAccountKeyPair

IDNotIn applies the NotIn predicate on the ID field.

func KeyID

KeyID applies equality check predicate on the "key_id" field. It's identical to KeyIDEQ.

func KeyIDContains

func KeyIDContains(v string) predicate.ServiceAccountKeyPair

KeyIDContains applies the Contains predicate on the "key_id" field.

func KeyIDContainsFold

func KeyIDContainsFold(v string) predicate.ServiceAccountKeyPair

KeyIDContainsFold applies the ContainsFold predicate on the "key_id" field.

func KeyIDEQ

KeyIDEQ applies the EQ predicate on the "key_id" field.

func KeyIDEqualFold

func KeyIDEqualFold(v string) predicate.ServiceAccountKeyPair

KeyIDEqualFold applies the EqualFold predicate on the "key_id" field.

func KeyIDGT

KeyIDGT applies the GT predicate on the "key_id" field.

func KeyIDGTE

KeyIDGTE applies the GTE predicate on the "key_id" field.

func KeyIDHasPrefix

func KeyIDHasPrefix(v string) predicate.ServiceAccountKeyPair

KeyIDHasPrefix applies the HasPrefix predicate on the "key_id" field.

func KeyIDHasSuffix

func KeyIDHasSuffix(v string) predicate.ServiceAccountKeyPair

KeyIDHasSuffix applies the HasSuffix predicate on the "key_id" field.

func KeyIDIn

func KeyIDIn(vs ...string) predicate.ServiceAccountKeyPair

KeyIDIn applies the In predicate on the "key_id" field.

func KeyIDLT

KeyIDLT applies the LT predicate on the "key_id" field.

func KeyIDLTE

KeyIDLTE applies the LTE predicate on the "key_id" field.

func KeyIDNEQ

KeyIDNEQ applies the NEQ predicate on the "key_id" field.

func KeyIDNotIn

func KeyIDNotIn(vs ...string) predicate.ServiceAccountKeyPair

KeyIDNotIn applies the NotIn predicate on the "key_id" field.

func KeyTypeEQ

KeyTypeEQ applies the EQ predicate on the "key_type" field.

func KeyTypeIn

func KeyTypeIn(vs ...KeyType) predicate.ServiceAccountKeyPair

KeyTypeIn applies the In predicate on the "key_type" field.

func KeyTypeNEQ

KeyTypeNEQ applies the NEQ predicate on the "key_type" field.

func KeyTypeNotIn

func KeyTypeNotIn(vs ...KeyType) predicate.ServiceAccountKeyPair

KeyTypeNotIn applies the NotIn predicate on the "key_type" field.

func KeyTypeValidator

func KeyTypeValidator(kt KeyType) error

KeyTypeValidator is a validator for the "key_type" field enum values. It is called by the builders before save.

func LastUsedAt

LastUsedAt applies equality check predicate on the "last_used_at" field. It's identical to LastUsedAtEQ.

func LastUsedAtEQ

func LastUsedAtEQ(v time.Time) predicate.ServiceAccountKeyPair

LastUsedAtEQ applies the EQ predicate on the "last_used_at" field.

func LastUsedAtGT

func LastUsedAtGT(v time.Time) predicate.ServiceAccountKeyPair

LastUsedAtGT applies the GT predicate on the "last_used_at" field.

func LastUsedAtGTE

func LastUsedAtGTE(v time.Time) predicate.ServiceAccountKeyPair

LastUsedAtGTE applies the GTE predicate on the "last_used_at" field.

func LastUsedAtIn

func LastUsedAtIn(vs ...time.Time) predicate.ServiceAccountKeyPair

LastUsedAtIn applies the In predicate on the "last_used_at" field.

func LastUsedAtIsNil

func LastUsedAtIsNil() predicate.ServiceAccountKeyPair

LastUsedAtIsNil applies the IsNil predicate on the "last_used_at" field.

func LastUsedAtLT

func LastUsedAtLT(v time.Time) predicate.ServiceAccountKeyPair

LastUsedAtLT applies the LT predicate on the "last_used_at" field.

func LastUsedAtLTE

func LastUsedAtLTE(v time.Time) predicate.ServiceAccountKeyPair

LastUsedAtLTE applies the LTE predicate on the "last_used_at" field.

func LastUsedAtNEQ

func LastUsedAtNEQ(v time.Time) predicate.ServiceAccountKeyPair

LastUsedAtNEQ applies the NEQ predicate on the "last_used_at" field.

func LastUsedAtNotIn

func LastUsedAtNotIn(vs ...time.Time) predicate.ServiceAccountKeyPair

LastUsedAtNotIn applies the NotIn predicate on the "last_used_at" field.

func LastUsedAtNotNil

func LastUsedAtNotNil() predicate.ServiceAccountKeyPair

LastUsedAtNotNil applies the NotNil predicate on the "last_used_at" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func PublicKeyPem

func PublicKeyPem(v string) predicate.ServiceAccountKeyPair

PublicKeyPem applies equality check predicate on the "public_key_pem" field. It's identical to PublicKeyPemEQ.

func PublicKeyPemContains

func PublicKeyPemContains(v string) predicate.ServiceAccountKeyPair

PublicKeyPemContains applies the Contains predicate on the "public_key_pem" field.

func PublicKeyPemContainsFold

func PublicKeyPemContainsFold(v string) predicate.ServiceAccountKeyPair

PublicKeyPemContainsFold applies the ContainsFold predicate on the "public_key_pem" field.

func PublicKeyPemEQ

func PublicKeyPemEQ(v string) predicate.ServiceAccountKeyPair

PublicKeyPemEQ applies the EQ predicate on the "public_key_pem" field.

func PublicKeyPemEqualFold

func PublicKeyPemEqualFold(v string) predicate.ServiceAccountKeyPair

PublicKeyPemEqualFold applies the EqualFold predicate on the "public_key_pem" field.

func PublicKeyPemGT

func PublicKeyPemGT(v string) predicate.ServiceAccountKeyPair

PublicKeyPemGT applies the GT predicate on the "public_key_pem" field.

func PublicKeyPemGTE

func PublicKeyPemGTE(v string) predicate.ServiceAccountKeyPair

PublicKeyPemGTE applies the GTE predicate on the "public_key_pem" field.

func PublicKeyPemHasPrefix

func PublicKeyPemHasPrefix(v string) predicate.ServiceAccountKeyPair

PublicKeyPemHasPrefix applies the HasPrefix predicate on the "public_key_pem" field.

func PublicKeyPemHasSuffix

func PublicKeyPemHasSuffix(v string) predicate.ServiceAccountKeyPair

PublicKeyPemHasSuffix applies the HasSuffix predicate on the "public_key_pem" field.

func PublicKeyPemIn

func PublicKeyPemIn(vs ...string) predicate.ServiceAccountKeyPair

PublicKeyPemIn applies the In predicate on the "public_key_pem" field.

func PublicKeyPemLT

func PublicKeyPemLT(v string) predicate.ServiceAccountKeyPair

PublicKeyPemLT applies the LT predicate on the "public_key_pem" field.

func PublicKeyPemLTE

func PublicKeyPemLTE(v string) predicate.ServiceAccountKeyPair

PublicKeyPemLTE applies the LTE predicate on the "public_key_pem" field.

func PublicKeyPemNEQ

func PublicKeyPemNEQ(v string) predicate.ServiceAccountKeyPair

PublicKeyPemNEQ applies the NEQ predicate on the "public_key_pem" field.

func PublicKeyPemNotIn

func PublicKeyPemNotIn(vs ...string) predicate.ServiceAccountKeyPair

PublicKeyPemNotIn applies the NotIn predicate on the "public_key_pem" field.

func Revoked

Revoked applies equality check predicate on the "revoked" field. It's identical to RevokedEQ.

func RevokedAt

RevokedAt applies equality check predicate on the "revoked_at" field. It's identical to RevokedAtEQ.

func RevokedAtEQ

RevokedAtEQ applies the EQ predicate on the "revoked_at" field.

func RevokedAtGT

RevokedAtGT applies the GT predicate on the "revoked_at" field.

func RevokedAtGTE

func RevokedAtGTE(v time.Time) predicate.ServiceAccountKeyPair

RevokedAtGTE applies the GTE predicate on the "revoked_at" field.

func RevokedAtIn

func RevokedAtIn(vs ...time.Time) predicate.ServiceAccountKeyPair

RevokedAtIn applies the In predicate on the "revoked_at" field.

func RevokedAtIsNil

func RevokedAtIsNil() predicate.ServiceAccountKeyPair

RevokedAtIsNil applies the IsNil predicate on the "revoked_at" field.

func RevokedAtLT

RevokedAtLT applies the LT predicate on the "revoked_at" field.

func RevokedAtLTE

func RevokedAtLTE(v time.Time) predicate.ServiceAccountKeyPair

RevokedAtLTE applies the LTE predicate on the "revoked_at" field.

func RevokedAtNEQ

func RevokedAtNEQ(v time.Time) predicate.ServiceAccountKeyPair

RevokedAtNEQ applies the NEQ predicate on the "revoked_at" field.

func RevokedAtNotIn

func RevokedAtNotIn(vs ...time.Time) predicate.ServiceAccountKeyPair

RevokedAtNotIn applies the NotIn predicate on the "revoked_at" field.

func RevokedAtNotNil

func RevokedAtNotNil() predicate.ServiceAccountKeyPair

RevokedAtNotNil applies the NotNil predicate on the "revoked_at" field.

func RevokedEQ

RevokedEQ applies the EQ predicate on the "revoked" field.

func RevokedNEQ

func RevokedNEQ(v bool) predicate.ServiceAccountKeyPair

RevokedNEQ applies the NEQ predicate on the "revoked" field.

func ServiceAccountID

func ServiceAccountID(v uuid.UUID) predicate.ServiceAccountKeyPair

ServiceAccountID applies equality check predicate on the "service_account_id" field. It's identical to ServiceAccountIDEQ.

func ServiceAccountIDEQ

func ServiceAccountIDEQ(v uuid.UUID) predicate.ServiceAccountKeyPair

ServiceAccountIDEQ applies the EQ predicate on the "service_account_id" field.

func ServiceAccountIDIn

func ServiceAccountIDIn(vs ...uuid.UUID) predicate.ServiceAccountKeyPair

ServiceAccountIDIn applies the In predicate on the "service_account_id" field.

func ServiceAccountIDNEQ

func ServiceAccountIDNEQ(v uuid.UUID) predicate.ServiceAccountKeyPair

ServiceAccountIDNEQ applies the NEQ predicate on the "service_account_id" field.

func ServiceAccountIDNotIn

func ServiceAccountIDNotIn(vs ...uuid.UUID) predicate.ServiceAccountKeyPair

ServiceAccountIDNotIn applies the NotIn predicate on the "service_account_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type Algorithm

type Algorithm string

Algorithm defines the type for the "algorithm" enum field.

const (
	AlgorithmRS256 Algorithm = "RS256"
	AlgorithmRS384 Algorithm = "RS384"
	AlgorithmRS512 Algorithm = "RS512"
	AlgorithmES256 Algorithm = "ES256"
	AlgorithmES384 Algorithm = "ES384"
	AlgorithmES512 Algorithm = "ES512"
)

Algorithm values.

func (Algorithm) String

func (a Algorithm) String() string

type KeyType

type KeyType string

KeyType defines the type for the "key_type" enum field.

const (
	KeyTypeRsa KeyType = "rsa"
	KeyTypeEc  KeyType = "ec"
)

KeyType values.

func (KeyType) String

func (kt KeyType) String() string

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ServiceAccountKeyPair queries.

func ByActive

func ByActive(opts ...sql.OrderTermOption) OrderOption

ByActive orders the results by the active field.

func ByAlgorithm

func ByAlgorithm(opts ...sql.OrderTermOption) OrderOption

ByAlgorithm orders the results by the algorithm field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByExpiresAt

func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption

ByExpiresAt orders the results by the expires_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByKeyID

func ByKeyID(opts ...sql.OrderTermOption) OrderOption

ByKeyID orders the results by the key_id field.

func ByKeyType

func ByKeyType(opts ...sql.OrderTermOption) OrderOption

ByKeyType orders the results by the key_type field.

func ByLastUsedAt

func ByLastUsedAt(opts ...sql.OrderTermOption) OrderOption

ByLastUsedAt orders the results by the last_used_at field.

func ByPublicKeyPem

func ByPublicKeyPem(opts ...sql.OrderTermOption) OrderOption

ByPublicKeyPem orders the results by the public_key_pem field.

func ByRevoked

func ByRevoked(opts ...sql.OrderTermOption) OrderOption

ByRevoked orders the results by the revoked field.

func ByRevokedAt

func ByRevokedAt(opts ...sql.OrderTermOption) OrderOption

ByRevokedAt orders the results by the revoked_at field.

func ByServiceAccountField

func ByServiceAccountField(field string, opts ...sql.OrderTermOption) OrderOption

ByServiceAccountField orders the results by service_account field.

func ByServiceAccountID

func ByServiceAccountID(opts ...sql.OrderTermOption) OrderOption

ByServiceAccountID orders the results by the service_account_id field.

Jump to